@@ -1,3 +1,4 @@
+import os
 import requests_cache
 from json.decoder import JSONDecodeError
 
@@ -7,6 +8,11 @@ _SESSIONS_BY_EXPIRY = {}
 
 def session(expiry=0):
     """Get a caching HTTP session"""
+
+     # Testing requires caching be disabled or tests may fetch network data from previous tests which would be incorrect.
+    if os.getenv("BLASEBALL_MIKE_NOCACHE", None):
+        expiry = 0
+
     if expiry not in _SESSIONS_BY_EXPIRY:
         _SESSIONS_BY_EXPIRY[expiry] = requests_cache.CachedSession(backend="memory", expire_after=expiry)
     return _SESSIONS_BY_EXPIRY[expiry]
